==> haskell-exceptions-0.10.4-20-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-exceptions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 exceptions
version:              0.10.4
visibility:           public
id:                   exceptions-0.10.4-JUrZHue9S26DL7DmYQK2uL
key:                  exceptions-0.10.4-JUrZHue9S26DL7DmYQK2uL
license:              BSD-3-Clause
copyright:
    Copyright (C) 2013-2015 Edward A. Kmett
    Copyright (C) 2012 Google Inc.

maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/exceptions/
synopsis:             Extensible optionally-pure exceptions
description:          Extensible optionally-pure exceptions.
category:             Control, Exceptions, Monad
abi:                  d5b45d6dc74beb17f4a6fab9a72c28e2
exposed:              True
exposed-modules:      Control.Monad.Catch Control.Monad.Catch.Pure
import-dirs:          /usr/lib/ghc-8.8.3/site-local/exceptions-0.10.4
library-dirs:         /usr/lib/ghc-8.8.3/site-local/exceptions-0.10.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/exceptions-0.10.4
hs-libraries:         HSexceptions-0.10.4-JUrZHue9S26DL7DmYQK2uL
depends:
    base-4.13.0.0 mtl-2.2.2 stm-2.5.0.0 template-haskell-2.15.0.0
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-exceptions/html/exceptions.haddock
haddock-html:         /usr/share/doc/haskell-exceptions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-exceptions-0.10.4-23-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-exceptions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 exceptions
version:              0.10.4
visibility:           public
id:                   exceptions-0.10.4-IWqfFitgKOeJT066q48Qo6
key:                  exceptions-0.10.4-IWqfFitgKOeJT066q48Qo6
license:              BSD-3-Clause
copyright:
    Copyright (C) 2013-2015 Edward A. Kmett
    Copyright (C) 2012 Google Inc.

maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/exceptions/
synopsis:             Extensible optionally-pure exceptions
description:          Extensible optionally-pure exceptions.
category:             Control, Exceptions, Monad
abi:                  23ab720f604bf553e7906ed4b1deb32f
exposed:              True
exposed-modules:      Control.Monad.Catch Control.Monad.Catch.Pure
import-dirs:          /usr/lib/ghc-8.8.3/site-local/exceptions-0.10.4
library-dirs:         /usr/lib/ghc-8.8.3/site-local/exceptions-0.10.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/exceptions-0.10.4
hs-libraries:         HSexceptions-0.10.4-IWqfFitgKOeJT066q48Qo6
depends:
    base-4.13.0.0 mtl-2.2.2 stm-2.5.0.0 template-haskell-2.15.0.0
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-exceptions/html/exceptions.haddock
haddock-html:         /usr/share/doc/haskell-exceptions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
